eprllib.RewardFunctions — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.RewardFunctions

## Reward Functions

This module contain the reward functions used in the reinforcement learning and implemented in eprllib.

You can implement your own reward function by creating a new class that inherits from `RewardFunction` and overriding the calculate_reward method.

Modules

`RewardFunctions` | Reward Funtion
`henderson_2024` | Henderson et al. (2024)